Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Version string
Version is the version of this tool.
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func GetVersion ¶
func GetVersion() string
GetVersion returns the version using the same logic as the version command
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.